==> digikam-4.2.0.tar.bz2: digikam-4.2.0/extra/kipi-plugins/imageshackexport/kipiplugin_imageshackexport.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Imageshack Export
Name=Imageshack Export
Name[bs]=Imageshack Izvoz
Name[ca]=Exportador a Imageshack
Name[ca@valencia]=Exportador a Imageshack
Name[cs]=Export do Imageshacku
Name[da]=Eksport til Imageshack
Name[de]=Imageshack-Export
Name[el]=Εξαγωγή Imageshack
Name[en_GB]=Imageshack Export
Name[es]=Exportar a Imageshack
Name[et]=Imageshacki eksport
Name[fi]=Imageshack-vienti
Name[fr]=Module externe pour l'export vers « Imageshack »
Name[ga]=Easpórtáil Imageshack
Name[gl]=Exportación a Imageshack
Name[hu]=Imageshack exportálás
Name[is]=Imageshack útflutningur
Name[it]=Esportazione a Imageshack
Name[nb]=Eksport til Imageshack
Name[nl]=Imageshack-export
Name[pl]=Eksportuj do Imageshack
Name[pt]=Exportação para o Imageshack
Name[pt_BR]=Exportar para o Imageshack
Name[ru]=Экспорт в ImageShack
Name[sk]=Imageshack Export
Name[sl]=Izvoz v Imageshack
Name[sv]=Export till Imageshack
Name[tr]=Imageshack Aktarımı
Name[uk]=Експорт до Imageshack
Name[x-test]=xxImageshack Exportxx
Name[zh_TW]=Imageshack 匯出
Comment=A tool to export images to Imageshack web service
Comment[bs]=Alat za izvoz slika u ImageShack web servisu
Comment[ca]=Una eina per exportar imatges al servei web Imageshack
Comment[ca@valencia]=Una eina per exportar imatges al servei web Imageshack
Comment[cs]=Nástroj pro export obrázků do webové služby Imageshack
Comment[da]=Et værktøj til at eksportere billeder til webtjenesten Imageshack
Comment[de]=Ein Werkzeug, um Bilder zu einem Imageshack-Webdienst zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων στην υπηρεσία ιστού Imageshack
Comment[en_GB]=A tool to export images to Imageshack web service
Comment[es]=Una herramienta para exportar imágenes al servicio web de Imageshack
Comment[et]=Tööriist piltide eksportimiseks Imageshacki veebiteenusesse
Comment[fr]=Outil pour l'exportation vers le service en ligne « Imageshack »
Comment[ga]=Uirlis a easpórtálann íomhánna go seirbhís Ghréasáin Imageshack
Comment[gl]=Ferramenta para exportar imaxes ao servizo web Imageshack.
Comment[hu]=Egy eszköz képek exportálásához Imageshack webszolgáltatásba
Comment[is]=Verkfæri til að senda myndir á Imageshack vefþjónustu
Comment[it]=Uno strumento per esportare immagini al servizio Web Imageshack
Comment[nb]=Et verktøy for å eksportere bilder til en Imageshack-nettjeneste
Comment[nl]=Een hulpmiddel om afbeeldingen naar de Imageshack-webservice te exporteren
Comment[pl]=Narzędzie do eksportowania obrazów do usługi sieciowej Imageshack
Comment[pt]=Uma ferramenta para exportar imagens para o serviço Web Imageshack
Comment[pt_BR]=Uma ferramenta para exportar imagens para o serviço da Internet Imageshack
Comment[ru]=Инструмент для экспорта изображений в веб-службу ImageShack
Comment[sk]=Nástroj na export obrázkov na službu Imageshack
Comment[sl]=Orodje za izvoz slik v oddaljeno spletno storitev Imageshack
Comment[sv]=Ett verktyg för att exportera bilder till en Imageshack webbtjänst
Comment[tr]=Resimleri Imageshack web hizmetine aktarmak için bir araç
Comment[uk]=Інструмент для експорту зображення до служби Imageshack
Comment[x-test]=xxA tool to export images to Imageshack web servicexx
Comment[zh_TW]=匯出影像到遠端 Imageshack 網頁服務的工具
Type=Service
Icon=kipi-imageshack
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_imageshackexport
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Victor Dodon, dodonvictor at gmail dot com

==> digikam-4.6.0.tar.bz2: digikam-4.6.0/extra/kipi-plugins/imageshackexport/kipiplugin_imageshackexport.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Imageshack Export
Name=Imageshack Export
Name[bs]=Imageshack Izvoz
Name[ca]=Exportador a Imageshack
Name[ca@valencia]=Exportador a Imageshack
Name[cs]=Export do Imageshacku
Name[da]=Eksport til Imageshack
Name[de]=Imageshack-Export
Name[el]=Εξαγωγή Imageshack
Name[en_GB]=Imageshack Export
Name[es]=Exportar a Imageshack
Name[et]=Imageshacki eksport
Name[fi]=Imageshack-vienti
Name[fr]=Module externe pour l'export vers « Imageshack »
Name[ga]=Easpórtáil Imageshack
Name[gl]=Exportación a Imageshack
Name[hu]=Imageshack exportálás
Name[is]=Imageshack útflutningur
Name[it]=Esportazione a Imageshack
Name[nb]=Eksport til Imageshack
Name[nl]=Imageshack-export
Name[pl]=Eksportuj do Imageshack
Name[pt]=Exportação para o Imageshack
Name[pt_BR]=Exportar para o Imageshack
Name[ru]=Экспорт в ImageShack
Name[sk]=Imageshack Export
Name[sl]=Izvoz v Imageshack
Name[sv]=Export till Imageshack
Name[tr]=Imageshack Aktarımı
Name[uk]=Експорт до Imageshack
Name[x-test]=xxImageshack Exportxx
Name[zh_TW]=Imageshack 匯出
Comment=A tool to export images to Imageshack web service
Comment[bs]=Alat za izvoz slika u ImageShack web servisu
Comment[ca]=Una eina per exportar imatges al servei web Imageshack
Comment[ca@valencia]=Una eina per exportar imatges al servei web Imageshack
Comment[cs]=Nástroj pro export obrázků do webové služby Imageshack
Comment[da]=Et værktøj til at eksportere billeder til webtjenesten Imageshack
Comment[de]=Ein Werkzeug, um Bilder zu einem Imageshack-Webdienst zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων στην υπηρεσία ιστού Imageshack
Comment[en_GB]=A tool to export images to Imageshack web service
Comment[es]=Una herramienta para exportar imágenes al servicio web de Imageshack
Comment[et]=Tööriist piltide eksportimiseks Imageshacki veebiteenusesse
Comment[fi]=Kuvien vienti Imageshack-verkkopalveluun
Comment[fr]=Outil pour l'exportation vers le service en ligne « Imageshack »
Comment[ga]=Uirlis a easpórtálann íomhánna go seirbhís Ghréasáin Imageshack
Comment[gl]=Ferramenta para exportar imaxes ao servizo web Imageshack.
Comment[hu]=Egy eszköz képek exportálásához Imageshack webszolgáltatásba
Comment[is]=Verkfæri til að senda myndir á Imageshack vefþjónustu
Comment[it]=Uno strumento per esportare immagini al servizio Web Imageshack
Comment[nb]=Et verktøy for å eksportere bilder til en Imageshack-nettjeneste
Comment[nl]=Een hulpmiddel om afbeeldingen naar de Imageshack-webservice te exporteren
Comment[pl]=Narzędzie do eksportowania obrazów do usługi sieciowej Imageshack
Comment[pt]=Uma ferramenta para exportar imagens para o serviço Web Imageshack
Comment[pt_BR]=Ferramenta para exportar imagens para o Imageshack
Comment[ru]=Инструмент для экспорта изображений в веб-службу ImageShack
Comment[sk]=Nástroj na export obrázkov na službu Imageshack
Comment[sl]=Orodje za izvoz slik v oddaljeno spletno storitev Imageshack
Comment[sv]=Ett verktyg för att exportera bilder till en Imageshack webbtjänst
Comment[tr]=Resimleri Imageshack web hizmetine aktarmak için bir araç
Comment[uk]=Інструмент для експорту зображення до служби Imageshack
Comment[x-test]=xxA tool to export images to Imageshack web servicexx
Comment[zh_TW]=匯出影像到遠端 Imageshack 網頁服務的工具
Type=Service
Icon=kipi-imageshack
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_imageshackexport
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Victor Dodon, dodonvictor at gmail dot com
